==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Günlüğü temizle</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Yenile</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Günlüğü silmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tümü</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Bugün</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 gün</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 hafta</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 ay</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 ay</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Dışa aktar</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Dışa aktar</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tümü</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Acil durum</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>İkaz</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Dikkat</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Hata ayıklama</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Giriş</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Açılış</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Süper kritik</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>İzleyici</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>METİN (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Aktarılıyor...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Dışa aktarım başarılı</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Dışa aktarılamadı</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Dosyaya Aktar</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Dönem:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Seviye:  </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Uygulama listesi:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Durum:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Etkinlik Türü:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Kullanıcı:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Eylem:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Açılış kaydı</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Kapatma kaydı</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Giriş kaydı</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Hata ayıklama</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Acil durum</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>İkaz</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Dikkat</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>İzleyici</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Süper kritik</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Günlük dosyası boş</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Günlük Görüntüleyici</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Günlük Görüntüleyici, sistem günlüklerini görüntülemek için kullanışlı bir araçtır.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Arama sonucu bulunamadı</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Seviye</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>İşlem</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Tarih ve Saat</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Kaynak</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Eylem</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Etkinlik Türü</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Seviye:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>İşlem:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Tarih ve Saat:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Bilgi:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Boş</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Kullanıcı:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Tarih ve Saat</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Sistem Günlüğü</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Çekirdek Günlüğü</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Açılış Günlüğü</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Dpkg Günlüğü</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin Günlüğü</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg Günlüğü</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Uygulama Günlüğü</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Açılış-Kapanış Etkinliği</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf Günlüğü</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Dosya yöneticisinde görüntüle</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Günlüğü temizle</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Yenile</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Günlüğü silmek istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tümü</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Bugün</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 gün</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 hafta</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 ay</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 ay</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Dışa aktar</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tümü</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Acil durum</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>İkaz</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Dikkat</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Hata ayıklama</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Giriş</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Açılış</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Süper kritik</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>İzleyici</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Kimlik doğrulama</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>İsteğe Bağlı Erişim Kontrolü</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Zorunlu erişim kontrolü</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Uzak</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Belge denetimi</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Diğer</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>METİN (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Aktarılıyor...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Dışa aktarım başarılı</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Dışa aktarılamadı</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Dosyaya Aktar</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Dönem:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Seviye:  </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Durum:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Etkinlik Türü:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Kullanıcı:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Eylem:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Açılış kaydı</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Kapatma kaydı</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Giriş kaydı</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Denetim Türü:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Uyarı</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Hata ayıklama</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Acil durum</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>İkaz</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritik</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Dikkat</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>İzleyici</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Süper kritik</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Günlük dosyası boş</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Günlük Görüntüleyici</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Günlük Görüntüleyici, sistem günlüklerini görüntülemek için kullanışlı bir araçtır.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Arama sonucu bulunamadı</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Seviye</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>İşlem</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Tarih ve Saat</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Bilgi</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Kaynak</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Eylem</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Etkinlik Türü</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Kullanıcı adı</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Seviye:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>İşlem:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Tarih ve Saat:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Bilgi:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Boş</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Kullanıcı:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Dosya Adı</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Değiştirilme Zamanı</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Tarih ve Saat</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Sistem Günlüğü</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Çekirdek Günlüğü</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Açılış Günlüğü</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Dpkg Günlüğü</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin Günlüğü</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg Günlüğü</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Uygulama Günlüğü</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Açılış-Kapanış Etkinliği</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf Günlüğü</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Diğer Log</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Özel Log</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Denetleme Logu</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Görüntüleme izniniz yok</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Yineleme sıklığı</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sn</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 dk</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 dak</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Yineleme yapma</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Tümünü Dışa Aktar</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Şimdi yinele</translation>
    </message>
</context>
</TS>
